/**
* Created by Zhang Haijun on 2017/8/29.
*/
// 查询参数封装优化
export function handleSearchParam (params) {
  // 设置参数
  const objParams = {};
  function setParams (sign, key, value) {
    if (objParams[sign]) {
      objParams[sign][key] = value;
    } else {
      objParams[sign] = {
        [key]: value
      };
    }
  }
  // 将参数处理为对象
  for (const a in params) {
    const value = params[a];
    // 对参数进行处理，去除空参数
    if (value === '' || value === undefined || value === null) continue;
    // 对key值进行处理
    const [key, sign = 'EQ'] = a.split(':');
    // 将sign全部转换为大写
    const signs = sign.toLocaleUpperCase();
    if (signs === 'RANGE') {
      const [first, second] = value;
      setParams('GET', key, first);
      setParams('LET', key, second);
      continue;
    }
    setParams(signs, key, value);
  }
  const result = [];
  for (const a in objParams) {
    result.push({ param: objParams[a], sign: a });
  }
  return JSON.stringify(result);
}
// 查询参数封装
export function formatSearchParam (param) {
  // 对参数进行处理，去除空参数
  let toObjFormat = function (obj) {
    for (let a in obj) {
      if (obj[a] === '') delete obj[a];
    }
    return obj;
  };
  let toTwo = function (str) {
    if (str.toString().length == 1) {
      str = '0' + str;
    }
    return str;
  };
  // 对时间进行处理
  let toFormatTime = function (time) {
    if (!time) return '';
    return time.getFullYear() + '/' + toTwo(time.getMonth() + 1) + '/' + toTwo(time.getDate()) + ' ' + toTwo(time.getHours()) + ':' + toTwo(time.getMinutes()) + ':' + toTwo(time.getSeconds());
  };
  let params = [];
  let lkParam = toObjFormat(param.lkParam || {});
  let eqParam = toObjFormat(param.eqParam || {});
  let ueqParam = toObjFormat(param.ueqParam || {});
  let getParam = toObjFormat(param.getParam || {});
  let letParam = toObjFormat(param.letParam || {});
  let nulParam = toObjFormat(param.nulParam || {});
  if (param.date) {
    for (let a in param.date) {
      let item = param.date[a];
      if (item) {
        getParam[a] = toFormatTime(item[0]);
        letParam[a] = toFormatTime(item[1]);
      }
    }
  }
  if (JSON.stringify(lkParam).length > 2) params.push({ param: lkParam, sign: 'LK' });
  if (JSON.stringify(eqParam).length > 2) params.push({ param: eqParam, sign: 'EQ' });
  if (JSON.stringify(ueqParam).length > 2) params.push({ param: ueqParam, sign: 'UEQ' });
  if (JSON.stringify(getParam).length > 2) params.push({ param: getParam, sign: 'GET' });
  if (JSON.stringify(letParam).length > 2) params.push({ param: letParam, sign: 'LET' });
  if (JSON.stringify(nulParam).length > 2) params.push({ param: nulParam, sign: 'NUL' });
  return JSON.stringify(params);
}
// 生成时间戳
export function makeTimeStamp () {
  let format = function (value) {
    if (value / 1 < 10) value = '0' + value;
    return value.toString();
  };
  let date = new Date();
  return date.getFullYear() + format(date.getMonth() + 1) + format(date.getDate()) + format(date.getHours()) + format(date.getMinutes()) + format(date.getSeconds());
}
// 将数字转换为正整数
export function toInteger (attr, data) {
  if (!data[attr]) return;
  data[attr] = Math.round(Math.abs(data[attr]));
}
